---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: 'Feature'
assignees: ''

---

## Problem description

### Is your feature request related to a problem?

A clear and concise description of what the problem is.
Ex. I'm always frustrated when [...]

## Change description

### Describe the solution you'd like

A clear and concise description of what you want to happen.

Whenever relevant, please provide a code sample, of what would be the syntax, the way you
meant to use:

```python
# Your code here

```

### Advantages

Explain why the current behavior is a problem, what the expected output/behavior
is, and why the expected output/behavior is a better solution.

### Describe alternatives you've considered

A clear and concise description of any alternative solutions or features you've considered.

## Additional context

Add any other context or information about the feature request here.
Please feel free to use whatever template makes sense.

Also, feel free to remove all sections and text that aren't relevant.
